@@ -58,49 +58,73 @@
  *	@(#)stddef.h	5.5 (Berkeley) 4/3/91
  */
 
-#ifndef __STDDEF_H__
+#if !defined(__STDDEF_H__)
+
+#if !defined(__need_wchar_t) && !defined(__need_size_t) \
+    && !defined(__need_ptrdiff_t) && !defined(__need_NULL) \
+    && !defined(__need_wint_t)
 #define __STDDEF_H__
+#endif /* none of __need_* defined */
 
-#include <machine/types.h>
-#include <machine/ansi.h>
+#include <_types.h>
 
-typedef	_BSD_PTRDIFF_T_	ptrdiff_t;
+#if defined(__STDDEF_H__) || defined(__need_ptrdiff_t)
+#ifndef _PTRDIFF_T
+#define _PTRDIFF_T
+typedef	__darwin_ptrdiff_t	ptrdiff_t;
+#endif /* _PTRDIFF_T */
+#endif /* __STDDEF_H__ || __need_ptrdiff_t */
 
-#ifndef	_BSD_SIZE_T_DEFINED_
-#define	_BSD_SIZE_T_DEFINED_
-typedef	_BSD_SIZE_T_	size_t;
-#endif
-
-#ifndef	_BSD_CT_RUNE_T_DEFINED_
-#define _BSD_CT_RUNE_T_DEFINED_
-typedef	_BSD_CT_RUNE_T_	ct_rune_t;
-#endif
-
-#ifndef	_BSD_RUNE_T_DEFINED_
-#define _BSD_RUNE_T_DEFINED_
-typedef	_BSD_RUNE_T_	rune_t;
-#endif
+#if defined(__STDDEF_H__) || defined(__need_size_t)
+#ifndef	_SIZE_T
+#define	_SIZE_T
+/* DO NOT REMOVE THIS COMMENT: fixincludes needs to see:
+ * _GCC_SIZE_T */
+typedef	__darwin_size_t		size_t;
+#endif /* _SIZE_T */
+#endif /* __STDDEF_H__ || __need_size_t */
 
+#if defined(__STDDEF_H__) || defined(__need_wchar_t)
 #ifndef	__cplusplus
-#ifndef	_BSD_WCHAR_T_DEFINED_
-#define	_BSD_WCHAR_T_DEFINED_
-#ifdef	__WCHAR_TYPE__
-typedef	__WCHAR_TYPE__	wchar_t;
-#else	/* ! __WCHAR_TYPE__ */
-typedef	_BSD_WCHAR_T_	wchar_t;
-#endif	/* __WCHAR_TYPE__ */
-#endif	/* _BSD_WCHAR_T_DEFINED_ */
+#ifndef	_WCHAR_T
+#define	_WCHAR_T
+typedef	__darwin_wchar_t	wchar_t;
+#endif	/* _WCHAR_T */
 #endif	/* __cplusplus */
+#endif /* __STDDEF_H__ || __need_wchar_t */
 
-#ifndef	_BSD_WINT_T_DEFINED_
-#define _BSD_WINT_T_DEFINED_
-typedef	_BSD_WINT_T_	wint_t;
+#if (defined(__STDDEF_H__) && !defined(_ANSI_SOURCE) && !defined(_POSIX_C_SOURCE)) \
+    || defined(__need_wint_t)
+#ifndef	_WINT_T
+#define	_WINT_T
+typedef	__darwin_wint_t		wint_t;
+#endif	/* _WINT_T */
+#endif /* __STDDEF_H__ && !_ANSI_SOURCE && !_POSIX_C_SOURCE || __need_wchar_t */
+
+#if defined(__STDDEF_H__) || defined(__need_NULL)
+#ifndef NULL
+#define NULL __DARWIN_NULL
+#endif /* ! NULL */
+#endif /* __STDDEF_H__ || __need_NULL */
+
+#ifdef __STDDEF_H__
+#if defined(__GNUC__) && (__GNUC__ == 3 && __GNUC_MINOR__ >= 5 || __GNUC__ > 3)
+#ifndef __offsetof	/* Deprecated: for source compatability only */
+#define __offsetof(type, field) __builtin_offsetof(type, field)
 #endif
-
-#ifndef	NULL
-#define	NULL	0
+#define offsetof(type, field) __builtin_offsetof(type, field)
+#else /* ! (gcc >= 3.5) */
+#ifndef __offsetof	/* Deprecated: for source compatability only */
+#define __offsetof(type, field) ((size_t)(&((type *)0)->field))
 #endif
-
-#define         offsetof(type, member)  __offsetof(type, member)
+#define offsetof(type, field) ((size_t)(&((type *)0)->field))
+#endif /* (gcc >= 3.5) */
+#endif /* __STDDEF_H__ */
 
 #endif /* __STDDEF_H__ */
+
+#undef __need_ptrdiff_t
+#undef __need_size_t
+#undef __need_wchar_t
+#undef __need_wint_t
+#undef __need_NULL
